/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  'User Name': 'User Name',
  'Please enter user name': 'Please enter user name',
  Password: 'Password',
  'Please enter your password': 'Please enter your password',
  'Password consists of at least two combinations of numbers, letters, and characters, and the length is between 6-22': 'Password consists of at least two combinations of numbers, letters, and characters, and the length is between 6-22',
  Login: 'Login',
  Home: 'Home',
  'Failed to create node to save': 'Failed to create node to save',
  'Global parameters': 'Global parameters',
  'Local parameters': 'Local parameters',
  'Copy success': 'Copy success',
  'The browser does not support automatic copying': 'The browser does not support automatic copying',
  'Whether to save the DAG graph': 'Whether to save the DAG graph',
  'Current node settings': 'Current node settings',
  'View history': 'View history',
  'View log': 'View log',
  'Force success': 'Force success',
  'Enter this child node': 'Enter this child node',
  'Node name': 'Node name',
  'Please enter name (required)': 'Please enter name (required)',
  'Run flag': 'Run flag',
  Normal: 'Normal',
  'Prohibition execution': 'Prohibition execution',
  'Please enter description': 'Please enter description',
  'Number of failed retries': 'Number of failed retries',
  Times: 'Times',
  'Failed retry interval': 'Failed retry interval',
  Minute: 'Minute',
  'Delay execution time': 'Delay execution time',
  'Delay execution': 'Delay execution',
  'Forced success': 'Forced success',
  Cancel: 'Cancel',
  'Confirm add': 'Confirm add',
  'The newly created sub-Process has not yet been executed and cannot enter the sub-Process': 'The newly created sub-Process has not yet been executed and cannot enter the sub-Process',
  'The task has not been executed and cannot enter the sub-Process': 'The task has not been executed and cannot enter the sub-Process',
  'Name already exists': 'Name already exists',
  'Download Log': 'Download Log',
  'Refresh Log': 'Refresh Log',
  'Enter full screen': 'Enter full screen',
  'Cancel full screen': 'Cancel full screen',
  Close: 'Close',
  'Update log success': 'Update log success',
  'No more logs': 'No more logs',
  'No log': 'No log',
  'Loading Log...': 'Loading Log...',
  'Set the DAG diagram name': 'Set the DAG diagram name',
  'Please enter description(optional)': 'Please enter description(optional)',
  'Set global': 'Set global',
  'Whether to go online the process definition': 'Whether to go online the process definition',
  'Whether to update the process definition': 'Whether to update the process definition',
  Add: 'Add',
  'DAG graph name cannot be empty': 'DAG graph name cannot be empty',
  'Create Datasource': 'Create Datasource',
  'Project Home': 'Workflow Monitor',
  'Project Manage': 'Project',
  'Create Project': 'Create Project',
  'Cron Manage': 'Cron Manage',
  'Copy Workflow': 'Copy Workflow',
  'Tenant Manage': 'Tenant Manage',
  'Create Tenant': 'Create Tenant',
  'User Manage': 'User Manage',
  'Create User': 'Create User',
  'User Information': 'User Information',
  'Edit Password': 'Edit Password',
  Success: 'Success',
  Failed: 'Failed',
  Delete: 'Delete',
  'Please choose': 'Please choose',
  'Please enter a positive integer': 'Please enter a positive integer',
  'Program Type': 'Program Type',
  'Main Class': 'Main Class',
  'Main Package': 'Main Package',
  'Please enter main package': 'Please enter main package',
  'Please enter main class': 'Please enter main class',
  'Main Arguments': 'Main Arguments',
  'Please enter main arguments': 'Please enter main arguments',
  'Option Parameters': 'Option Parameters',
  'Please enter option parameters': 'Please enter option parameters',
  Resources: 'Resources',
  'Custom Parameters': 'Custom Parameters',
  'Custom template': 'Custom template',
  Datasource: 'Datasource',
  methods: 'methods',
  'Please enter the procedure method': 'Please enter the procedure script \n\ncall procedure:{call <procedure-name>[(<arg1>,<arg2>, ...)]}\n\ncall function:{?= call <procedure-name>[(<arg1>,<arg2>, ...)]} ',
  'The procedure method script example': 'example:{call <procedure-name>[(?,?, ...)]} or {?= call <procedure-name>[(?,?, ...)]}',
  Script: 'Script',
  'Please enter script(required)': 'Please enter script(required)',
  'Deploy Mode': 'Deploy Mode',
  'Driver Cores': 'Driver Cores',
  'Please enter Driver cores': 'Please enter Driver cores',
  'Driver Memory': 'Driver Memory',
  'Please enter Driver memory': 'Please enter Driver memory',
  'Executor Number': 'Executor Number',
  'Please enter Executor number': 'Please enter Executor number',
  'The Executor number should be a positive integer': 'The Executor number should be a positive integer',
  'Executor Memory': 'Executor Memory',
  'Please enter Executor memory': 'Please enter Executor memory',
  'Executor Cores': 'Executor Cores',
  'Please enter Executor cores': 'Please enter Executor cores',
  'Memory should be a positive integer': 'Memory should be a positive integer',
  'Core number should be positive integer': 'Core number should be positive integer',
  'Flink Version': 'Flink Version',
  'JobManager Memory': 'JobManager Memory',
  'Please enter JobManager memory': 'Please enter JobManager memory',
  'TaskManager Memory': 'TaskManager Memory',
  'Please enter TaskManager memory': 'Please enter TaskManager memory',
  'Slot Number': 'Slot Number',
  'Please enter Slot number': 'Please enter Slot number',
  Parallelism: 'Parallelism',
  'Custom Parallelism': 'Configure parallelism',
  'Please enter Parallelism': 'Please enter Parallelism',
  'Parallelism tip': 'If there are a large number of tasks requiring complement, you can use the custom parallelism to ' +
  'set the complement task thread to a reasonable value to avoid too large impact on the server.',
  'Parallelism number should be positive integer': 'Parallelism number should be positive integer',
  'TaskManager Number': 'TaskManager Number',
  'Please enter TaskManager number': 'Please enter TaskManager number',
  'App Name': 'App Name',
  'Please enter app name(optional)': 'Please enter app name(optional)',
  'SQL Type': 'SQL Type',
  'Send Email': 'Send Email',
  'Log display': 'Log display',
  'rows of result': 'rows of result',
  Title: 'Title',
  'Please enter the title of email': 'Please enter the title of email',
  Table: 'Table',
  TableMode: 'Table',
  Attachment: 'Attachment',
  'SQL Parameter': 'SQL Parameter',
  'SQL Statement': 'SQL Statement',
  'UDF Function': 'UDF Function',
  'Please enter a SQL Statement(required)': 'Please enter a SQL Statement(required)',
  'Please enter a JSON Statement(required)': 'Please enter a JSON Statement(required)',
  'One form or attachment must be selected': 'One form or attachment must be selected',
  'Mail subject required': 'Mail subject required',
  'Child Node': 'Child Node',
  'Please select a sub-Process': 'Please select a sub-Process',
  Edit: 'Edit',
  'Switch To This Version': 'Switch To This Version',
  'Datasource Name': 'Datasource Name',
  'Please enter datasource name': 'Please enter datasource name',
  IP: 'IP',
  'Please enter IP': 'Please enter IP',
  Port: 'Port',
  'Please enter port': 'Please enter port',
  'Database Name': 'Database Name',
  'Please enter database name': 'Please enter database name',
  'Oracle Connect Type': 'ServiceName or SID',
  'Oracle Service Name': 'ServiceName',
  'Oracle SID': 'SID',
  'jdbc connect parameters': 'jdbc connect parameters',
  'Test Connect': 'Test Connect',
  'Please enter resource name': 'Please enter resource name',
  'Please enter resource folder name': 'Please enter resource folder name',
  'Please enter a non-query SQL statement': 'Please enter a non-query SQL statement',
  'Please enter IP/hostname': 'Please enter IP/hostname',
  'jdbc connection parameters is not a correct JSON format': 'jdbc connection parameters is not a correct JSON format',
  '#': '#',
  'Datasource Type': 'Datasource Type',
  'Datasource Parameter': 'Datasource Parameter',
  'Create Time': 'Create Time',
  'Update Time': 'Update Time',
  Operation: 'Operation',
  'Current Version': 'Current Version',
  'Click to view': 'Click to view',
  'Delete?': 'Delete?',
  'Switch Version Successfully': 'Switch Version Successfully',
  'Confirm Switch To This Version?': 'Confirm Switch To This Version?',
  Confirm: 'Confirm',
  'Task status statistics': 'Task Status Statistics',
  Number: 'Number',
  State: 'State',
  'Dry-run flag': 'Dry-run flag',
  'Process Status Statistics': 'Process Status Statistics',
  'Process Definition Statistics': 'Process Definition Statistics',
  'Project Name': 'Project Name',
  'Please enter name': 'Please enter name',
  'Owned Users': 'Owned Users',
  'Process Pid': 'Process Pid',
  'Zk registration directory': 'Zk registration directory',
  cpuUsage: 'cpuUsage',
  memoryUsage: 'memoryUsage',
  diskAvailable: 'diskAvailable',
  'Last heartbeat time': 'Last heartbeat time',
  'Edit Tenant': 'Edit Tenant',
  'OS Tenant Code': 'OS Tenant Code',
  'Tenant Name': 'Tenant Name',
  Queue: 'Yarn Queue',
  'Please select a queue': 'default is tenant association queue',
  'Please enter the os tenant code in English': 'Please enter the os tenant code in English',
  'Please enter os tenant code in English': 'Please enter os tenant code in English',
  'Please enter os tenant code': 'Please enter os tenant code',
  'Please enter tenant Name': 'Please enter tenant Name',
  'The os tenant code. Only letters or a combination of letters and numbers are allowed': 'The os tenant code. Only letters or a combination of letters and numbers are allowed',
  'Edit User': 'Edit User',
  Tenant: 'Tenant',
  Email: 'Email',
  Phone: 'Phone',
  'User Type': 'User Type',
  'Please enter phone number': 'Please enter phone number',
  'Please enter email': 'Please enter email',
  'Please enter the correct email format': 'Please enter the correct email format',
  'Please enter the correct mobile phone format': 'Please enter the correct mobile phone format',
  Project: 'Project',
  Authorize: 'Authorize',
  'File resources': 'File resources',
  'UDF resources': 'UDF resources',
  'UDF resources directory': 'UDF resources directory',
  'Please select UDF resources directory': 'Please select UDF resources directory',
  'Alarm group': 'Alarm group',
  'Alarm group required': 'Alarm group required',
  'Edit alarm group': 'Edit alarm group',
  'Create alarm group': 'Create alarm group',
  'Create Alarm Instance': 'Create Alarm Instance',
  'Edit Alarm Instance': 'Edit Alarm Instance',
  'Group Name': 'Group Name',
  'Alarm instance name': 'Alarm instance name',
  'Alarm plugin name': 'Alarm plugin name',
  'Select plugin': 'Select plugin',
  'Select Alarm plugin': 'Please select an Alarm plugin',
  'Please enter group name': 'Please enter group name',
  'Instance parameter exception': 'Instance parameter exception',
  'Group Type': 'Group Type',
  'Alarm plugin instance': 'Alarm plugin instance',
  'Please enter alarm plugin instance name': 'Please enter alarm plugin instance name',
  'Select Alarm plugin instance': 'Please select an Alarm plugin instance',
  Remarks: 'Remarks',
  SMS: 'SMS',
  'Managing Users': 'Managing Users',
  Permission: 'Permission',
  Administrator: 'Administrator',
  'Confirm Password': 'Confirm Password',
  'Please enter confirm password': 'Please enter confirm password',
  'Password cannot be in Chinese': 'Password cannot be in Chinese',
  'Please enter a password (6-22) character password': 'Please enter a password (6-22) character password',
  'Confirmation password cannot be in Chinese': 'Confirmation password cannot be in Chinese',
  'Please enter a confirmation password (6-22) character password': 'Please enter a confirmation password (6-22) character password',
  'The password is inconsistent with the confirmation password': 'The password is inconsistent with the confirmation password',
  'Please select the datasource': 'Please select the datasource',
  'Please select resources': 'Please select resources',
  Query: 'Query',
  'Non Query': 'Non Query',
  'prop(required)': 'prop(required)',
  'value(optional)': 'value(optional)',
  'value(required)': 'value(required)',
  'prop is empty': 'prop is empty',
  'value is empty': 'value is empty',
  'prop is repeat': 'prop is repeat',
  'Start Time': 'Start Time',
  'End Time': 'End Time',
  crontab: 'crontab',
  'Failure Strategy': 'Failure Strategy',
  online: 'online',
  offline: 'offline',
  'Task Status': 'Task Status',
  'Process Instance': 'Process Instance',
  'Task Instance': 'Task Instance',
  'Select date range': 'Select date range',
  startDate: 'startDate',
  endDate: 'endDate',
  Date: 'Date',
  Waiting: 'Waiting',
  Execution: 'Execution',
  Finish: 'Finish',
  'Create File': 'Create File',
  'Create folder': 'Create folder',
  'File Name': 'File Name',
  'Folder Name': 'Folder Name',
  'File Format': 'File Format',
  'Folder Format': 'Folder Format',
  'File Content': 'File Content',
  'Upload File Size': 'Upload File size cannot exceed 1g',
  Create: 'Create',
  'Please enter the resource content': 'Please enter the resource content',
  'Resource content cannot exceed 3000 lines': 'Resource content cannot exceed 3000 lines',
  'File Details': 'File Details',
  'Download Details': 'Download Details',
  Return: 'Return',
  Save: 'Save',
  'File Manage': 'File Manage',
  'Upload Files': 'Upload Files',
  'Create UDF Function': 'Create UDF Function',
  'Upload UDF Resources': 'Upload UDF Resources',
  'Service-Master': 'Service-Master',
  'Service-Worker': 'Service-Worker',
  'Process Name': 'Process Name',
  Executor: 'Executor',
  'Run Type': 'Run Type',
  'Scheduling Time': 'Scheduling Time',
  'Run Times': 'Run Times',
  host: 'host',
  'fault-tolerant sign': 'fault-tolerant sign',
  Rerun: 'Rerun',
  'Recovery Failed': 'Recovery Failed',
  Stop: 'Stop',
  Pause: 'Pause',
  'Recovery Suspend': 'Recovery Suspend',
  Gantt: 'Gantt',
  'Node Type': 'Node Type',
  'Submit Time': 'Submit Time',
  Duration: 'Duration',
  'Retry Count': 'Retry Count',
  'Task Name': 'Task Name',
  'Task Date': 'Task Date',
  'Source Table': 'Source Table',
  'Record Number': 'Record Number',
  'Target Table': 'Target Table',
  'Online viewing type is not supported': 'Online viewing type is not supported',
  Size: 'Size',
  Rename: 'Rename',
  Download: 'Download',
  Export: 'Export',
  'Version Info': 'Version Info',
  Submit: 'Submit',
  'Edit UDF Function': 'Edit UDF Function',
  type: 'type',
  'UDF Function Name': 'UDF Function Name',
  FILE: 'FILE',
  UDF: 'UDF',
  'File Subdirectory': 'File Subdirectory',
  'Please enter a function name': 'Please enter a function name',
  'Package Name': 'Package Name',
  'Please enter a Package name': 'Please enter a Package name',
  Parameter: 'Parameter',
  'Please enter a parameter': 'Please enter a parameter',
  'UDF Resources': 'UDF Resources',
  'Upload Resources': 'Upload Resources',
  Instructions: 'Instructions',
  'Please enter a instructions': 'Please enter a instructions',
  'Please enter a UDF function name': 'Please enter a UDF function name',
  'Select UDF Resources': 'Select UDF Resources',
  'Class Name': 'Class Name',
  'Jar Package': 'Jar Package',
  'Library Name': 'Library Name',
  'UDF Resource Name': 'UDF Resource Name',
  'File Size': 'File Size',
  Description: 'Description',
  'Drag Nodes and Selected Items': 'Drag Nodes and Selected Items',
  'Select Line Connection': 'Select Line Connection',
  'Delete selected lines or nodes': 'Delete selected lines or nodes',
  'Full Screen': 'Full Screen',
  Unpublished: 'Unpublished',
  'Start Process': 'Start Process',
  'Execute from the current node': 'Execute from the current node',
  'Recover tolerance fault process': 'Recover tolerance fault process',
  'Resume the suspension process': 'Resume the suspension process',
  'Execute from the failed nodes': 'Execute from the failed nodes',
  'Complement Data': 'Complement Data',
  'Scheduling execution': 'Scheduling execution',
  'Recovery waiting thread': 'Recovery waiting thread',
  'Submitted successfully': 'Submitted successfully',
  Executing: 'Executing',
  'Ready to pause': 'Ready to pause',
  'Ready to stop': 'Ready to stop',
  'Need fault tolerance': 'Need fault tolerance',
  Kill: 'Kill',
  'Waiting for thread': 'Waiting for thread',
  'Waiting for dependence': 'Waiting for dependence',
  Start: 'Start',
  Copy: 'Copy',
  'Copy name': 'Copy name',
  'Copy path': 'Copy path',
  'Please enter keyword': 'Please enter keyword',
  'File Upload': 'File Upload',
  'Drag the file into the current upload window': 'Drag the file into the current upload window',
  'Drag area upload': 'Drag area upload',
  Upload: 'Upload',
  'ReUpload File': 'ReUpload File',
  'Please enter file name': 'Please enter file name',
  'Please select the file to upload': 'Please select the file to upload',
  'Resources manage': 'Resources',
  Security: 'Security',
  Logout: 'Logout',
  'No data': 'No data',
  'Uploading...': 'Uploading...',
  'Loading...': 'Loading...',
  List: 'List',
  'Unable to download without proper url': 'Unable to download without proper url',
  Process: 'Process',
  'Process definition': 'Process definition',
  'Task record': 'Task record',
  'Warning group manage': 'Warning group manage',
  'Warning instance manage': 'Warning instance manage',
  'Servers manage': 'Servers manage',
  'UDF manage': 'UDF manage',
  'Resource manage': 'Resource manage',
  'Function manage': 'Function manage',
  'Edit password': 'Edit password',
  'Ordinary users': 'Ordinary users',
  'Create process': 'Create process',
  'Import process': 'Import process',
  'Timing state': 'Timing state',
  Timing: 'Timing',
  Timezone: 'Timezone',
  TreeView: 'TreeView',
  'Mailbox already exists! Recipients and copyers cannot repeat': 'Mailbox already exists! Recipients and copyers cannot repeat',
  'Mailbox input is illegal': 'Mailbox input is illegal',
  'Please set the parameters before starting': 'Please set the parameters before starting',
  Continue: 'Continue',
  End: 'End',
  'Node execution': 'Node execution',
  'Backward execution': 'Backward execution',
  'Forward execution': 'Forward execution',
  'Execute only the current node': 'Execute only the current node',
  'Notification strategy': 'Notification strategy',
  'Notification group': 'Notification group',
  'Please select a notification group': 'Please select a notification group',
  'Whether it is a complement process?': 'Whether it is a complement process?',
  'Schedule date': 'Schedule date',
  'Mode of execution': 'Mode of execution',
  'Serial execution': 'Serial execution',
  'Parallel execution': 'Parallel execution',
  'Set parameters before timing': 'Set parameters before timing',
  'Start and stop time': 'Start and stop time',
  'Please select time': 'Please select time',
  'Please enter crontab': 'Please enter crontab',
  none_1: 'none',
  success_1: 'success',
  failure_1: 'failure',
  All_1: 'All',
  Toolbar: 'Toolbar',
  'View variables': 'View variables',
  'Format DAG': 'Format DAG',
  'Refresh DAG status': 'Refresh DAG status',
  Return_1: 'Return',
  'Please enter format': 'Please enter format',
  'connection parameter': 'connection parameter',
  'Process definition details': 'Process definition details',
  'Create process definition': 'Create process definition',
  'Scheduled task list': 'Scheduled task list',
  'Process instance details': 'Process instance details',
  'Create Resource': 'Create Resource',
  'User Center': 'User Center',
  AllStatus: 'All',
  None: 'None',
  Name: 'Name',
  'Process priority': 'Process priority',
  'Task priority': 'Task priority',
  'Task timeout alarm': 'Task timeout alarm',
  'Timeout strategy': 'Timeout strategy',
  'Timeout alarm': 'Timeout alarm',
  'Timeout failure': 'Timeout failure',
  'Timeout period': 'Timeout period',
  'Waiting Dependent complete': 'Waiting Dependent complete',
  'Waiting Dependent start': 'Waiting Dependent start',
  'Check interval': 'Check interval',
  'Timeout must be longer than check interval': 'Timeout must be longer than check interval',
  'Timeout strategy must be selected': 'Timeout strategy must be selected',
  'Timeout must be a positive integer': 'Timeout must be a positive integer',
  'Add dependency': 'Add dependency',
  'Whether dry-run': 'Whether dry-run',
  and: 'and',
  or: 'or',
  month: 'month',
  week: 'week',
  day: 'day',
  hour: 'hour',
  Running: 'Running',
  'Waiting for dependency to complete': 'Waiting for dependency to complete',
  Selected: 'Selected',
  CurrentHour: 'CurrentHour',
  Last1Hour: 'Last1Hour',
  Last2Hours: 'Last2Hours',
  Last3Hours: 'Last3Hours',
  Last24Hours: 'Last24Hours',
  today: 'today',
  Last1Days: 'Last1Days',
  Last2Days: 'Last2Days',
  Last3Days: 'Last3Days',
  Last7Days: 'Last7Days',
  ThisWeek: 'ThisWeek',
  LastWeek: 'LastWeek',
  LastMonday: 'LastMonday',
  LastTuesday: 'LastTuesday',
  LastWednesday: 'LastWednesday',
  LastThursday: 'LastThursday',
  LastFriday: 'LastFriday',
  LastSaturday: 'LastSaturday',
  LastSunday: 'LastSunday',
  ThisMonth: 'ThisMonth',
  LastMonth: 'LastMonth',
  LastMonthBegin: 'LastMonthBegin',
  LastMonthEnd: 'LastMonthEnd',
  'Refresh status succeeded': 'Refresh status succeeded',
  'Queue manage': 'Yarn Queue manage',
  'Create queue': 'Create queue',
  'Edit queue': 'Edit queue',
  'Datasource manage': 'Datasource',
  'History task record': 'History task record',
  'Please go online': 'Please go online',
  'Queue value': 'Queue value',
  'Please enter queue value': 'Please enter queue value',
  'Worker group manage': 'Worker group manage',
  'Create worker group': 'Create worker group',
  'Edit worker group': 'Edit worker group',
  'Token manage': 'Token manage',
  'Create token': 'Create token',
  'Edit token': 'Edit token',
  Addresses: 'Addresses',
  'Worker Addresses': 'Worker Addresses',
  'Please select the worker addresses': 'Please select the worker addresses',
  'Failure time': 'Failure time',
  'Expiration time': 'Expiration time',
  User: 'User',
  'Please enter token': 'Please enter token',
  'Generate token': 'Generate token',
  Monitor: 'Monitor',
  Group: 'Group',
  'Queue statistics': 'Queue statistics',
  'Command status statistics': 'Command status statistics',
  'Task kill': 'Task Kill',
  'Task queue': 'Task queue',
  'Error command count': 'Error command count',
  'Normal command count': 'Normal command count',
  Manage: ' Manage',
  'Number of connections': 'Number of connections',
  Sent: 'Sent',
  Received: 'Received',
  'Min latency': 'Min latency',
  'Avg latency': 'Avg latency',
  'Max latency': 'Max latency',
  'Node count': 'Node count',
  'Query time': 'Query time',
  'Node self-test status': 'Node self-test status',
  'Health status': 'Health status',
  'Max connections': 'Max connections',
  'Threads connections': 'Threads connections',
  'Max used connections': 'Max used connections',
  'Threads running connections': 'Threads running connections',
  'Worker group': 'Worker group',
  'Please enter a positive integer greater than 0': 'Please enter a positive integer greater than 0',
  'Pre Statement': 'Pre Statement',
  'Post Statement': 'Post Statement',
  'Statement cannot be empty': 'Statement cannot be empty',
  'Process Define Count': 'Work flow Define Count',
  'Process Instance Running Count': 'Process Instance Running Count',
  'command number of waiting for running': 'command number of waiting for running',
  'failure command number': 'failure command number',
  'tasks number of waiting running': 'tasks number of waiting running',
  'task number of ready to kill': 'task number of ready to kill',
  'Statistics manage': 'Statistics Manage',
  statistics: 'Statistics',
  'select tenant': 'select tenant',
  'Please enter Principal': 'Please enter Principal',
  'Please enter the kerberos authentication parameter java.security.krb5.conf': 'Please enter the kerberos authentication parameter java.security.krb5.conf',
  'Please enter the kerberos authentication parameter login.user.keytab.username': 'Please enter the kerberos authentication parameter login.user.keytab.username',
  'Please enter the kerberos authentication parameter login.user.keytab.path': 'Please enter the kerberos authentication parameter login.user.keytab.path',
  'The start time must not be the same as the end': 'The start time must not be the same as the end',
  'Startup parameter': 'Startup parameter',
  'Startup type': 'Startup type',
  'warning of timeout': 'warning of timeout',
  'Next five execution times': 'Next five execution times',
  'Execute time': 'Execute time',
  'Complement range': 'Complement range',
  'Http Url': 'Http Url',
  'Http Method': 'Http Method',
  'Http Parameters': 'Http Parameters',
  'Http Parameters Key': 'Http Parameters Key',
  'Http Parameters Position': 'Http Parameters Position',
  'Http Parameters Value': 'Http Parameters Value',
  'Http Check Condition': 'Http Check Condition',
  'Http Condition': 'Http Condition',
  'Please Enter Http Url': 'Please Enter Http Url(required)',
  'Please Enter Http Condition': 'Please Enter Http Condition',
  'There is no data for this period of time': 'There is no data for this period of time',
  'Worker addresses cannot be empty': 'Worker addresses cannot be empty',
  'Please generate token': 'Please generate token',
  'Please Select token': 'Please select the expiration time of token',
  'Spark Version': 'Spark Version',
  TargetDataBase: 'target database',
  TargetTable: 'target table',
  TargetJobName: 'target job name',
  'Please enter Pigeon job name': 'Please enter Pigeon job name',
  'Please enter the table of target': 'Please enter the table of target',
  'Please enter a Target Table(required)': 'Please enter a Target Table(required)',
  SpeedByte: 'speed(byte count)',
  SpeedRecord: 'speed(record count)',
  '0 means unlimited by byte': '0 means unlimited',
  '0 means unlimited by count': '0 means unlimited',
  'Modify User': 'Modify User',
  'Whether directory': 'Whether directory',
  Yes: 'Yes',
  No: 'No',
  'Hadoop Custom Params': 'Hadoop Params',
  'Sqoop Advanced Parameters': 'Sqoop Params',
  'Sqoop Job Name': 'Job Name',
  'Please enter Mysql Database(required)': 'Please enter Mysql Database(required)',
  'Please enter Mysql Table(required)': 'Please enter Mysql Table(required)',
  'Please enter Columns (Comma separated)': 'Please enter Columns (Comma separated)',
  'Please enter Target Dir(required)': 'Please enter Target Dir(required)',
  'Please enter Export Dir(required)': 'Please enter Export Dir(required)',
  'Please enter Hive Database(required)': 'Please enter Hive Databasec(required)',
  'Please enter Hive Table(required)': 'Please enter Hive Table(required)',
  'Please enter hive target dir': 'Please enter hive target dir',
  'Please enter Hive Partition Keys': 'Please enter Hive Partition Key',
  'Please enter Hive Partition Values': 'Please enter Partition Value',
  'Please enter Replace Delimiter': 'Please enter Replace Delimiter',
  'Please enter Fields Terminated': 'Please enter Fields Terminated',
  'Please enter Lines Terminated': 'Please enter Lines Terminated',
  'Please enter Concurrency': 'Please enter Concurrency',
  'Please enter Update Key': 'Please enter Update Key',
  'Please enter Job Name(required)': 'Please enter Job Name(required)',
  'Please enter Custom Shell(required)': 'Please enter Custom Shell(required)',
  Direct: 'Direct',
  Type: 'Type',
  ModelType: 'ModelType',
  ColumnType: 'ColumnType',
  Database: 'Database',
  Column: 'Column',
  'Map Column Hive': 'Map Column Hive',
  'Map Column Java': 'Map Column Java',
  'Export Dir': 'Export Dir',
  'Hive partition Keys': 'Hive partition Keys',
  'Hive partition Values': 'Hive partition Values',
  FieldsTerminated: 'FieldsTerminated',
  LinesTerminated: 'LinesTerminated',
  IsUpdate: 'IsUpdate',
  UpdateKey: 'UpdateKey',
  UpdateMode: 'UpdateMode',
  'Target Dir': 'Target Dir',
  DeleteTargetDir: 'DeleteTargetDir',
  FileType: 'FileType',
  CompressionCodec: 'CompressionCodec',
  CreateHiveTable: 'CreateHiveTable',
  DropDelimiter: 'DropDelimiter',
  OverWriteSrc: 'OverWriteSrc',
  ReplaceDelimiter: 'ReplaceDelimiter',
  Concurrency: 'Concurrency',
  Form: 'Form',
  OnlyUpdate: 'OnlyUpdate',
  AllowInsert: 'AllowInsert',
  'Data Source': 'Data Source',
  'Data Target': 'Data Target',
  'All Columns': 'All Columns',
  'Some Columns': 'Some Columns',
  'Branch flow': 'Branch flow',
  'Custom Job': 'Custom Job',
  'Custom Script': 'Custom Script',
  'Cannot select the same node for successful branch flow and failed branch flow': 'Cannot select the same node for successful branch flow and failed branch flow',
  'Successful branch flow and failed branch flow are required': 'conditions node Successful and failed branch flow are required',
  'No resources exist': 'No resources exist',
  'Please delete all non-existing resources': 'Please delete all non-existing resources',
  'Unauthorized or deleted resources': 'Unauthorized or deleted resources',
  'Please delete all non-existent resources': 'Please delete all non-existent resources',
  Kinship: 'Workflow relationship',
  Reset: 'Reset',
  KinshipStateActive: 'Current selection',
  KinshipState1: 'Online',
  KinshipState0: 'Workflow is not online',
  KinshipState10: 'Scheduling is not online',
  'Dag label display control': 'Dag label display control',
  Enable: 'Enable',
  Disable: 'Disable',
  'The Worker group no longer exists, please select the correct Worker group!': 'The Worker group no longer exists, please select the correct Worker group!',
  'Please confirm whether the workflow has been saved before downloading': 'Please confirm whether the workflow has been saved before downloading',
  'User name length is between 3 and 39': 'User name length is between 3 and 39',
  'Timeout Settings': 'Timeout Settings',
  'Connect Timeout': 'Connect Timeout',
  'Socket Timeout': 'Socket Timeout',
  'Connect timeout be a positive integer': 'Connect timeout be a positive integer',
  'Socket Timeout be a positive integer': 'Socket Timeout be a positive integer',
  ms: 'ms',
  'Please Enter Url': 'Please Enter Url eg. 127.0.0.1:7077',
  Master: 'Master',
  'Please select the waterdrop resources': 'Please select the waterdrop resources',
  zkDirectory: 'zkDirectory',
  'Directory detail': 'Directory detail',
  'Connection name': 'Connection name',
  'Current connection settings': 'Current connection settings',
  'Please save the DAG before formatting': 'Please save the DAG before formatting',
  'Batch copy': 'Batch copy',
  'Related items': 'Related items',
  'Project name is required': 'Project name is required',
  'Batch move': 'Batch move',
  Version: 'Version',
  'Pre tasks': 'Pre tasks',
  'Running Memory': 'Running Memory',
  'Max Memory': 'Max Memory',
  'Min Memory': 'Min Memory',
  'The workflow canvas is abnormal and cannot be saved, please recreate': 'The workflow canvas is abnormal and cannot be saved, please recreate',
  Info: 'Info',
  'Datasource userName': 'owner',
  'Resource userName': 'owner',
  'Environment manage': 'Environment manage',
  'Create environment': 'Create environment',
  'Edit environment': 'Edit environment',
  'Environment value': 'Environment value',
  'Environment Name': 'Environment Name',
  'Environment Code': 'Environment Code',
  'Environment Config': 'Environment Config',
  'Environment Desc': 'Environment Desc',
  'Environment Worker Group': 'Worker Groups',
  'Please enter environment config': 'Please enter environment config',
  'Please enter environment desc': 'Please enter environment desc',
  'Please select worker groups': 'Please select worker groups',
  condition: 'condition',
  'The condition content cannot be empty': 'The condition content cannot be empty',
  'Reference from': 'Reference from',
  'No more...': 'No more...',
  'Task Definition': 'Task Definition',
  'Create task': 'Create task',
  'Task Type': 'Task Type',
  'Process execute type': 'Process execute type',
  parallel: 'parallel',
  'Serial wait': 'Serial wait',
  'Serial discard': 'Serial discard',
  'Serial priority': 'Serial priority',
  'Recover serial wait': 'Recover serial wait',
  IsEnableProxy: 'Enable Proxy',
  WebHook: 'WebHook',
  webHook: 'WebHook',
  Keyword: 'Keyword',
  Secret: 'Secret',
  MsgType: 'MsgType',
  AtMobiles: '@Mobiles',
  AtUserIds: '@UserIds',
  IsAtAll: '@All',
  Proxy: 'Proxy',
  receivers: 'Receivers',
  receiverCcs: 'ReceiverCcs',
  transportProtocol: 'Transport Protocol',
  serverHost: 'SMTP Host',
  serverPort: 'SMTP Port',
  sender: 'Sender',
  enableSmtpAuth: 'SMTP Auth',
  starttlsEnable: 'SMTP STARTTLS Enable',
  sslEnable: 'SMTP SSL Enable',
  smtpSslTrust: 'SMTP SSL Trust',
  url: 'URL',
  requestType: 'Request Type',
  headerParams: 'Headers',
  bodyParams: 'Body',
  contentField: 'Content Field',
  path: 'Script Path',
  userParams: 'User Params',
  corpId: 'CorpId',
  secret: 'Secret',
  userSendMsg: 'UserSendMsg',
  agentId: 'AgentId',
  users: 'Users',
  Username: 'Username',
  username: 'Username',
  showType: 'Show Type',
  'Please select a task type (required)': 'Please select a task type (required)',
  layoutType: 'Layout Type',
  gridLayout: 'Grid',
  dagreLayout: 'Dagre',
  rows: 'Rows',
  cols: 'Cols',
  processOnline: 'Online',
  searchNode: 'Search Node',
  dagScale: 'Scale',
  workflowName: 'Workflow Name',
  scheduleStartTime: 'Schedule Start Time',
  scheduleEndTime: 'Schedule End Time',
  crontabExpression: 'Crontab',
  workflowPublishStatus: 'Workflow Publish Status',
  schedulePublishStatus: 'Schedule Publish Status'
}
